/******************************************************************************
* C Include: Astronomy Tools                                                  *
*                                                                             *
* File:                                                                       *
*    astronomy.h                                                              *
*                                                                             *
* Description:                                                                *
*    Include file for the functions that perform various astronomical tasks.  *
*                                                                             *
* History:                                                                    *
*    Created    : 13-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#ifndef __ASTROMNY__
#define __ASTROMNY__

#include <stdio.h>

#include "generic.h"

/****************************
* Astronomy Tools constants *
****************************/

#define GREAT_CIRCLE_EPSILON  .001 /* Arcseconds */
#define PI                    3.1415926535
#define ARCSECONDS_PER_RADIAN 206264.8062470964
#define SECONDS_PER_RADIAN    (ARCSECONDS_PER_RADIAN/15.0)

/*************************************
* Astronomy Tools derived data types *
*************************************/
enum equinox { B1950 = 0, J2000 = 1 };
typedef enum equinox EQUINOX;

/****************************************
* Astronomy Tools function's prototypes *
****************************************/
extern void   b1950_j2000            (/* double  in_ra         ,
					 double  in_dec        ,
					 double *out_ra        ,
					 double *out_dec        */);

extern void   condmsrd               (/* int     ra_h          ,
					 int     ra_m          ,
					 double  ra_s          ,
					 char    dec_sign      ,
					 int     dec_d         ,
					 int     dec_m         ,
					 double  dec_s         ,
					 double *object_ra     ,
					 double *object_dec     */);




/**************************************
* Astronomy Tools include file page 2 *
**************************************/

extern void   conrddms               (/* double  ra            ,
					 double  dec           ,
					 int    *ra_h          ,
					 int    *ra_m          ,
					 double *ra_s          ,
					 char   *dec_sign      ,
					 int    *dec_d         ,
					 int    *dec_m         ,
					 double *dec_s          */);

       double Great_Circle_Separation(/* double  RA_1          ,
					 double  Dec_1         ,
					 double  RA_2          ,
					 double  Dec_2          */);

       int    Read_DMS               (/* FILE   *Input_File    ,
					 double *RA            ,
					 double *Dec 	        */);

extern void   traneqstd              (/* double  plt_center_ra ,
					 double  plt_center_dec,
					 double  object_ra     ,
					 double  object_dec    ,
					 double *object_xi     ,
					 double *object_eta     */);

extern void   transtdeq              (/* double  plt_center_ra ,
					 double  plt_center_dec,
					 double  xi            ,
					 double  eta           ,
					 double *ra            ,
					 double *dec            */);

       void   Write_DMS              (/* FILE   *Output_File   ,
					 double  RA            ,
					 double  Dec           ,
					 STRING  Format         */);

#endif
